@@ -135,6 +135,9 @@ class ConnectWiseBoard(TimeStampedModel):
 
     name = models.CharField(max_length=255)
     inactive = models.BooleanField(default=False)
+    time_entry_discussion_flag = models.BooleanField(default=False)
+    time_entry_resolution_flag = models.BooleanField(default=False)
+    time_entry_internal_analysis_flag = models.BooleanField(default=False)
     work_role = models.ForeignKey(
         'WorkRole',
         blank=True,
